"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var path = require("path");
var parser_1 = require("../parser");
function check(component, expected, exactProperties) {
    if (exactProperties === void 0) { exactProperties = true; }
    var fileName = path.join(__dirname, '../../src/__tests__/data', component + ".tsx"); // it's running in ./temp
    var result = parser_1.parse(fileName);
    checkComponent(result, expected, exactProperties);
}
exports.check = check;
function checkComponent(actual, expected, exactProperties) {
    if (exactProperties === void 0) { exactProperties = true; }
    var expectedComponentNames = Object.getOwnPropertyNames(expected);
    chai_1.assert.equal(actual.length, expectedComponentNames.length, "The number of expected components is different - \r\nexpected: " + expectedComponentNames + ", \r\nactual: " + actual.map(function (i) { return i.displayName; }));
    var errors = [];
    var _loop_1 = function (expectedComponentName) {
        var expectedComponent = expected[expectedComponentName];
        var componentDocs = actual.filter(function (i) { return i.displayName === expectedComponentName; });
        if (componentDocs.length === 0) {
            errors.push("Component is missing - " + expectedComponentName);
            return "continue";
        }
        var componentDoc = componentDocs[0];
        var expectedPropNames = Object.getOwnPropertyNames(expectedComponent);
        var propNames = Object.getOwnPropertyNames(componentDoc.props);
        var compName = componentDoc.displayName;
        if (componentDoc.description !== compName + " description") {
            errors.push(compName + " description is different - expected: '" + compName + " description', actual: '" + componentDoc.description + "'");
        }
        if (propNames.length !== expectedPropNames.length && exactProperties === true) {
            errors.push("Properties for " + compName + " are different - expected: " + expectedPropNames.length + ", actual: " + propNames.length + " (" + JSON.stringify(expectedPropNames) + ", " + JSON.stringify(propNames) + ")");
        }
        for (var _i = 0, expectedPropNames_1 = expectedPropNames; _i < expectedPropNames_1.length; _i++) {
            var expectedPropName = expectedPropNames_1[_i];
            var expectedProp = expectedComponent[expectedPropName];
            var prop = componentDoc.props[expectedPropName];
            if (prop === undefined) {
                errors.push("Property '" + compName + "." + expectedPropName + "' is missing");
            }
            else {
                if (expectedProp.type !== prop.type.name) {
                    errors.push("Property '" + compName + "." + expectedPropName + "' type is different - expected: " + expectedProp.type + ", actual: " + prop.type.name);
                }
                var expectedDescription = expectedProp.description === undefined ? expectedPropName + " description" : expectedProp.description;
                if (expectedDescription !== prop.description) {
                    errors.push("Property '" + compName + "." + expectedPropName + "' description is different - expected: " + expectedDescription + ", actual: " + prop.description);
                }
                var expectedRequired = expectedProp.required === undefined ? true : expectedProp.required;
                if (expectedRequired !== prop.required) {
                    errors.push("Property '" + compName + "." + expectedPropName + "' required is different - expected: " + expectedRequired + ", actual: " + prop.required);
                }
            }
        }
    };
    for (var _i = 0, expectedComponentNames_1 = expectedComponentNames; _i < expectedComponentNames_1.length; _i++) {
        var expectedComponentName = expectedComponentNames_1[_i];
        _loop_1(expectedComponentName);
    }
    var ok = errors.length === 0;
    if (!ok) {
        console.log(JSON.stringify(actual, null, 4));
    }
    chai_1.assert(ok, errors.join('\r\n'));
}
exports.checkComponent = checkComponent;
//# sourceMappingURL=testUtils.js.map